@@ -36,7 +36,7 @@ describe 'swift::storage::server' do
         'foo'
       end
 
-      it_raises 'a Puppet::Error', /does not match/
+      it { should raise_error(Puppet::Error) }
     end
 
     ['account', 'object', 'container'].each do |t|
@@ -84,7 +84,7 @@ describe 'swift::storage::server' do
 
           describe "when pipeline is not passed an array" do
             let :params do req_params.merge({:pipeline => 'not an array'}) end
-            it_raises 'a Puppet::Error', /is not an Array/
+            it { should raise_error(Puppet::Error) }
           end
 
           describe "when replicator_concurrency is set" do
@@ -111,6 +111,16 @@ describe 'swift::storage::server' do
             end
           end
 
+          if t == 'object'
+            describe "when splice is not set" do
+             it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^splice\s*=\s*false\s*$/) }
+            end
+            describe "when splice is set" do
+             let :params do req_params.merge({ :splice => true, }) end
+              it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^splice\s*=\s*true\s*$/) }
+            end
+          end
+
           describe "when log_udp_port is set" do
             context 'and log_udp_host is not set' do
               let :params do req_params.merge({ :log_udp_port => 514}) end
